#!/bin/bash
#
# Copyright (c) 2012-2013, NetApp, Inc. All rights reserved
#
# This file contains common functions for all scripts.
#
# Function: checkAvailableSpace
# returns :
# desc    : Checks available disk space, prompts a user if there is not enough
#           to proceed and terminates after a keypress.

function checkAvailableSpace() {
        echo
        echo "Checking available disk space."
        echo
        declare -i maxAllowedUsedDiskSpacePercentage=$1
        spaceUsed=`df -h | grep "^/dev/mapper" | awk '{ print $5 }'`
        declare -i spacePercentage=${spaceUsed%%\%}

        if [[ $spacePercentage -gt $maxAllowedUsedDiskSpacePercentage ]]; then
                echo "Unable to perform operation due to available disk space limitations."
                read -r -p "Remove temporary files in order to recover disk space? (Y/n)" answer

                if [[ "$answer" == "y" ]] || [[ "$answer" == "Y" ]] || [[ "$answer" == "" ]]; then
                    sudo /usr/share/vapp/tbd/freeTmpSpace.sh

                    spaceUsed=`df -h | grep "^/dev/mapper" | awk '{ print $5 }'`
                    declare -i spacePercentage=${spaceUsed%%\%}
                    if [[ $spacePercentage -gt $maxAllowedUsedDiskSpacePercentage ]]; then
                        echo "Unable to perform operation due to available disk space limitations."
                        echo "Please add additional storage to this Virtual Machine or contact customer support for assistance."
                        read -r -p "Press any key to continue." answer
                        logOut
                    fi
                else
                    logOut
                fi
        fi
}

# Function: calculateUsedSpace
# returns :
# desc    : returns the used disk space
function calculateUsedSpace() {
    echo
    echo "Calculating used disk space"
    echo
    spaceUsed=`df -h | grep "^/dev/mapper" | awk '{ print $5 }'`
    declare -i spacePercentage=${spaceUsed%%\%}

    return $spacePercentage
}


# Function : umountCdrom
# returns  :
# desc     : Unmounts the cdrom if possible.
function umountCdrom()
{
    umount /cdrom &> /dev/null
}

# Function : logOut
# returns  :
# desc     : Calls clean up methods and exits the script
function logOut()
{
    umountCdrom

    echo
    exit
}

#
# Method for displaying an editable field
#
function displayEditField()
{
    # Input parameters:
    #  $1 = prompt
    #  $2 = current setting
    #  $3 = hidden or not
    prompt=$1
    current=$2
    hidden=$3
    new=$current

    # Place the current position at the end of the current
    currpos=${#current}

    # Now lets let the user input what they want
    echo -n "$prompt $current"
    while [[ 1 ]]
    do
        # Read one character at a time to look throught the data
        read -sn 1 char

        # If the character is the escape, then read 5 more.  We are
        # trying to remove the ability to use the arrow keys
        key=$( echo $char | od -t x1 | awk '{print $2}' )
        if [[ $key == "1b" ]]
        then
            loop=5
            while [[ $loop != 0 ]]
            do
                read -sn 1 char
                #echo $char
                loop=$((loop-1))
            done
            continue
        fi

        # This is the backspace character
        if [[ $char == "" ]]
        then
            # Need to make sure we do not allow the user to go beyond the
            # current.
            if [[ $currpos -ne 0 ]]
            then
                echo -e -n "\b \b"
                # Need to subtract from the current pos and as well,
                # need to subtract from new
                currpos=$((currpos-1))
                new=${new:0:$currpos}
            fi
        elif [[ $char == "" ]] || [[ $char == "\n" ]] || [[ $char == "" ]]
        then
            g_output=$new
            return 0
        elif [[ $char == "[1;5A" ]] || [[ $char == "[1;5C" ]]
        then
            continue
        else
            # We need to add a new character to the new and update our
            # current position
            if [[ ! "$hidden" ]]
            then
                echo -n $char
            fi
            new=$new$char
            currpos=$((currpos+1))
        fi
    done
}

##
############################################################################################
############################################################################################
