#!/bin/bash

PATH=/sbin:/bin:/usr/bin:/usr/sbin

# Source the branded-company file
. /etc/COMPANY_BRAND_FILE

version=`cat /etc/installer_version`
VERSION=$version
FIRSTBOOT_TOUCH_DIR="/var/lib/fmc/firstboot"
FIRSTBOOT_TOUCH_FILE_2=${FIRSTBOOT_TOUCH_DIR}/firstboot2-${VERSION}.run

OUR_IP=$(ifconfig eth0|grep 'inet addr'|awk '{print $2}'|sed 's/addr://g')

/usr/bin/clear > /dev/tty1

if [ -a ${FIRSTBOOT_TOUCH_FILE_2} ]; then
  echo "$VENDOR_NAME Flash Accel Management Console (FMC) $version." > /dev/tty1
  echo "Installation, configuration and management of Flash Accel caching" > /dev/tty1
  echo "in a VMware vSphere environment." > /dev/tty1
  echo "" > /dev/tty1
  echo "" > /dev/tty1
  echo "" > /dev/tty1
  echo "Please connect to http://$OUR_IP for configuring and using FMC." > /dev/tty1
  echo "" > /dev/tty1
  echo "" > /dev/tty1
  echo "" > /dev/tty1
  echo "" > /dev/tty1
  echo "For more information or support please visit $VENDOR_URL." > /dev/tty1
  echo "" > /dev/tty1
  echo "" > /dev/tty1
  echo "Login as \"$VENDOR_LC_NAME\" for the Advanced Management Terminal." > /dev/tty1
  echo "" > /dev/tty1
  exit 0
fi

echo "" > /dev/tty1
echo "Initial boot detected.  Performing one-time configuration steps and" > /dev/tty1
echo "rebooting." > /dev/tty1
echo "" > /dev/tty1

# See if the Base-MC Debian package was included on the OVA... If so, install it!!!
if [ -e /usr/share/debian-pkgs/"$VENDOR_NAME"_FlashAccel-Base-MC*.deb ]
then
    # Install the clients
    dpkg -i /usr/share/debian-pkgs/"$VENDOR_NAME"_FlashAccel-Base-MC*.deb
fi

# Install FMC package
dpkg -i /usr/share/debian-pkgs/flashaccel-fmc*.deb

# Install ASUP
dpkg -i /usr/share/debian-pkgs/FlashAccel-ASUP*.deb

# Relocate the database files to /opt/flashaccel/mysql  (separate disk on FMC VM)
service mysql stop
/bin/rm -rf /opt/flashaccel/mysql/*
/bin/cp -R -p /var/lib/mysql/ /opt/flashaccel/
/bin/rm -rf /var/lib/mysql
/bin/ln -s /opt/flashaccel/mysql/ /var/lib/mysql
# The following line is required as mysql looks at all the files under
# its datadir which is currently pointed at /var/lib/mysql, and this enables 
# a clean restart. This is because the InnoDB engine may be disabled 
/bin/rm -rf /var/lib/mysql/ib_logfile*
service mysql start

# Install FMC Database
mysql -u root < /var/www/mercury_nocontent.sql
service mysql restart

# Allow drupal (www-data) to backup contents
/bin/chmod -R 775 /opt/flashaccel/flashaccel
/bin/chgrp -R www-data /opt/flashaccel/flashaccel

# Allow users to mount cdrom
/bin/sed -i -e 's/defaults,noauto/defaults,noauto,user/g' /etc/fstab

# If this script does not exist, we can't use it (comes from ASUP Debian pkg)
if [ -e /usr/share/asup/XMLconfig.pl ]; then

  # This script prints key=value pairs from the OVF form. "eval" makes the END vars (getting $adminPassword)
  eval `/usr/share/asup/XMLconfig.pl`

  # Make sure password is not blank
  if [ "$adminPassword" != "" ]; then

    # Update the "admin" password on FAMC
    /usr/share/vapp/scripts/update_admin_passwd.php "$adminPassword"

    # Update the "AMT" password per vendor-login
    echo -e "$adminPassword\n$adminPassword"| (passwd $VENDOR_LC_NAME)

  fi
fi

# Create the flag to indicate that this script has been executed
touch ${FIRSTBOOT_TOUCH_FILE_2}

# Reboot to ensure we come up with a consistent configuration on first
# and second+ boots.
/sbin/reboot
