#!/bin/bash
echo "Enter vmwareupgrade ..." &>> /var/log/firstboot.log
date &>> /var/log/firstboot.log

# Check if VMware Tools is not already installed
if [ ! -e /usr/sbin/vmware-tools-upgrader ]
then
   # Extract the VMware Tools tarball into the tmp directory
   # The cat command is used because tar does not accept wild cards in the file name parameter
   cat /usr/share/vapp/vmware/VMwareTools-*.tar.gz | tar xz -C /tmp &> /var/log/vmware-tools-install.log

   # Install the 4.0.0 version of tools
   /tmp/vmware-tools-distrib/vmware-install.pl -default &>> /var/log/vmware-tools-install.log
   echo "Extracted tar and Installed VMware tools ..." >> /var/log/firstboot.log
   date &>> /var/log/firstboot.log

fi

# Upgrade to the latest version of tools available
/usr/sbin/vmware-tools-upgrader -p "--default --clobber-kernel-modules=pvscsi,vmxnet3" &>> /var/log/vmware-tools-install.log

# Search the log file for a Usage error message from the upgrader script. This indicates the --clobber-kernel-modules option is
# not valid for the version of tools that's being upgraded to (the option was introduced in VMware 4.1.0). This search is 
# necessary because the vmware-tools-upgrader program does not give a bad error code when the installation command fails.

echo "VMware tools upgrade with Non default options" &>> /var/log/firstboot.log
date &>> /var/log/firstboot.log

grep 'Usage.*vmware-install.pl' /var/log/vmware-tools-install.log &> /dev/null
if [ "$?" -eq "0" ]
  then
    # If the --clobber-kernel-modules option wasn't valid, retry the upgrade with just the default options
    echo "Retrying upgrade without --clobber-kernel-modules option" &>> /var/log/vmware-tools-install.log
    /usr/sbin/vmware-tools-upgrader -p "--default" &>> /var/log/vmware-tools-install.log

   echo "VMware tools upgrade with default options" &>> /var/log/firstboot.log
   date &>> /var/log/firstboot.log

fi

# Restart networking to use the new net driver 
/etc/init.d/networking stop &>> /var/log/vmware-tools-install.log
/sbin/rmmod pcnet32 &>> /var/log/vmware-tools-install.log
/sbin/rmmod vmxnet &>> /var/log/vmware-tools-install.log
/sbin/modprobe vmxnet &>> /var/log/vmware-tools-install.log
# If the loading of the vmxnet module failed, re-introduce the pcnet32 module so networking won't fail
if [ "$?" -ne "0" ]
  then
     /sbin/modprobe pcnet32 &>> /var/log/vmware-tools-install.log
fi

/etc/init.d/networking start &>> /var/log/vmware-tools-install.log

# Cleanup the tmp directory
rm -rf /tmp/vmware-tools-distrib

echo "Exit VMware Tools Install upgrade" &>> /var/log/firstboot.log
date &>> /var/log/firstboot.log
